@@ -190,7 +190,7 @@ godot_versions = {
     ':3.2::windows:64:'             : 'https://downloads.tuxfamily.org/godotengine/3.2/Godot_v3.2-stable_win64.exe.zip',
     ':3.2::darwin:64:'              : 'https://downloads.tuxfamily.org/godotengine/3.2/Godot_v3.2-stable_osx.64.zip',
     ':3.2::linux:32:'               : 'https://downloads.tuxfamily.org/godotengine/3.2/Godot_v3.2-stable_x11.32.zip',
-    ':3.2::linux:64:'               : 'https://downloads.tuxfamily.org/godotengine/3.2/Godot_v3.2-3dsteeeeeeeeeeeeable_x11.64.zip',
+    ':3.2::linux:64:'               : 'https://downloads.tuxfamily.org/godotengine/3.2/Godot_v3.2-stable_x11.64.zip',
     ':3.2::windows:32:mono'         : 'https://downloads.tuxfamily.org/godotengine/3.2/mono/Godot_v3.2-stable_win32.exe.zip',
     ':3.2::windows:64:mono'         : 'https://downloads.tuxfamily.org/godotengine/3.2/mono/Godot_v3.2-stable_win64.exe.zip',
     ':3.2::darwin:64:mono'          : 'https://downloads.tuxfamily.org/godotengine/3.2/mono/Godot_v3.2-stable_osx.64.zip',
@@ -295,4 +295,92 @@ godot_versions = {
     ':3.4::linux:64:mono'           : 'https://downloads.tuxfamily.org/godotengine/3.4/mono/Godot_v3.4-stable_mono_x11_64.zip',
     ':3.4::windows:64:mono'         : 'https://downloads.tuxfamily.org/godotengine/3.4/mono/Godot_v3.4-stable_mono_win32.zip',
     ':3.4::windows:32:mono'         : 'https://downloads.tuxfamily.org/godotengine/3.4/mono/Godot_v3.4-stable_mono_win64.zip',
+# 3.4.1
+    ':3.4.1::darwin::'           	: 'https://downloads.tuxfamily.org/godotengine/3.4.1/Godot_v3.4.1-stable_osx.universal.zip',
+    ':3.4.1::linux:32:'               : 'https://downloads.tuxfamily.org/godotengine/3.4.1/Godot_v3.4.1-stable_x11.32.zip',
+    ':3.4.1::linux:64:'               : 'https://downloads.tuxfamily.org/godotengine/3.4.1/Godot_v3.4.1-stable_x11.64.zip',
+    ':3.4.1::windows:64:'             : 'https://downloads.tuxfamily.org/godotengine/3.4.1/Godot_v3.4.1-stable_win64.exe.zip',
+    ':3.4.1::windows:32:'             : 'https://downloads.tuxfamily.org/godotengine/3.4.1/Godot_v3.4.1-stable_win32.exe.zip',
+    ':3.4.1::darwin::mono'            : 'https://downloads.tuxfamily.org/godotengine/3.4.1/mono/Godot_v3.4.1-stable_mono_osx.64.zip',
+    ':3.4.1::linux:32:mono'           : 'https://downloads.tuxfamily.org/godotengine/3.4.1/mono/Godot_v3.4.1-stable_mono_x11_32.zip',
+    ':3.4.1::linux:64:mono'           : 'https://downloads.tuxfamily.org/godotengine/3.4.1/mono/Godot_v3.4.1-stable_mono_x11_64.zip',
+    ':3.4.1::windows:64:mono'         : 'https://downloads.tuxfamily.org/godotengine/3.4.1/mono/Godot_v3.4.1-stable_mono_win32.zip',
+    ':3.4.1::windows:32:mono'         : 'https://downloads.tuxfamily.org/godotengine/3.4.1/mono/Godot_v3.4.1-stable_mono_win64.zip',
+# 3.4.2
+    ':3.4.2::darwin::'                : 'https://downloads.tuxfamily.org/godotengine/3.4.2/Godot_v3.4.2-stable_osx.universal.zip',
+    ':3.4.2::linux:32:'               : 'https://downloads.tuxfamily.org/godotengine/3.4.2/Godot_v3.4.2-stable_x11.32.zip',
+    ':3.4.2::linux:64:'               : 'https://downloads.tuxfamily.org/godotengine/3.4.2/Godot_v3.4.2-stable_x11.64.zip',
+    ':3.4.2::windows:64:'             : 'https://downloads.tuxfamily.org/godotengine/3.4.2/Godot_v3.4.2-stable_win64.exe.zip',
+    ':3.4.2::windows:32:'             : 'https://downloads.tuxfamily.org/godotengine/3.4.2/Godot_v3.4.2-stable_win32.exe.zip',
+    ':3.4.2::darwin::mono'            : 'https://downloads.tuxfamily.org/godotengine/3.4.2/mono/Godot_v3.4.2-stable_mono_osx.universal.zip',
+    ':3.4.2::linux:32:mono'           : 'https://downloads.tuxfamily.org/godotengine/3.4.2/mono/Godot_v3.4.2-stable_mono_x11_32.zip',
+    ':3.4.2::linux:64:mono'           : 'https://downloads.tuxfamily.org/godotengine/3.4.2/mono/Godot_v3.4.2-stable_mono_x11_64.zip',
+    ':3.4.2::windows:64:mono'         : 'https://downloads.tuxfamily.org/godotengine/3.4.2/mono/Godot_v3.4.2-stable_mono_win32.zip',
+    ':3.4.2::windows:32:mono'         : 'https://downloads.tuxfamily.org/godotengine/3.4.2/mono/Godot_v3.4.2-stable_mono_win64.zip',
+# 3.4.3
+    ':3.4.3::darwin::'                : 'https://downloads.tuxfamily.org/godotengine/3.4.3/Godot_v3.4.3-stable_osx.universal.zip',
+    ':3.4.3::linux:32:'               : 'https://downloads.tuxfamily.org/godotengine/3.4.3/Godot_v3.4.3-stable_x11.32.zip',
+    ':3.4.3::linux:64:'               : 'https://downloads.tuxfamily.org/godotengine/3.4.3/Godot_v3.4.3-stable_x11.64.zip',
+    ':3.4.3::windows:64:'             : 'https://downloads.tuxfamily.org/godotengine/3.4.3/Godot_v3.4.3-stable_win64.exe.zip',
+    ':3.4.3::windows:32:'             : 'https://downloads.tuxfamily.org/godotengine/3.4.3/Godot_v3.4.3-stable_win32.exe.zip',
+    ':3.4.3::darwin::mono'            : 'https://downloads.tuxfamily.org/godotengine/3.4.3/mono/Godot_v3.4.3-stable_mono_osx.universal.zip',
+    ':3.4.3::linux:32:mono'           : 'https://downloads.tuxfamily.org/godotengine/3.4.3/mono/Godot_v3.4.3-stable_mono_x11_32.zip',
+    ':3.4.3::linux:64:mono'           : 'https://downloads.tuxfamily.org/godotengine/3.4.3/mono/Godot_v3.4.3-stable_mono_x11_64.zip',
+    ':3.4.3::windows:64:mono'         : 'https://downloads.tuxfamily.org/godotengine/3.4.3/mono/Godot_v3.4.3-stable_mono_win32.zip',
+    ':3.4.3::windows:32:mono'         : 'https://downloads.tuxfamily.org/godotengine/3.4.3/mono/Godot_v3.4.3-stable_mono_win64.zip',
+# 3.4.4
+    ':3.4.4::darwin::'                  : 'https://downloads.tuxfamily.org/godotengine/3.4.4/Godot_v3.4.4-stable_osx.universal.zip',
+    ':3.4.4::linux:32:'                 : 'https://downloads.tuxfamily.org/godotengine/3.4.4/Godot_v3.4.4-stable_x11.32.zip',
+    ':3.4.4::linux:64:'                 : 'https://downloads.tuxfamily.org/godotengine/3.4.4/Godot_v3.4.4-stable_x11.64.zip',
+    ':3.4.4::windows:64:'               : 'https://downloads.tuxfamily.org/godotengine/3.4.4/Godot_v3.4.4-stable_win64.exe.zip',
+    ':3.4.4::windows:32:'               : 'https://downloads.tuxfamily.org/godotengine/3.4.4/Godot_v3.4.4-stable_win32.exe.zip',
+    ':3.4.4::darwin::mono'              : 'https://downloads.tuxfamily.org/godotengine/3.4.4/mono/Godot_v3.4.4-stable_mono_osx.universal.zip',
+    ':3.4.4::linux:32:mono'             : 'https://downloads.tuxfamily.org/godotengine/3.4.4/mono/Godot_v3.4.4-stable_mono_x11_32.zip',
+    ':3.4.4::linux:64:mono'             : 'https://downloads.tuxfamily.org/godotengine/3.4.4/mono/Godot_v3.4.4-stable_mono_x11_64.zip',
+    ':3.4.4::windows:64:mono'           : 'https://downloads.tuxfamily.org/godotengine/3.4.4/mono/Godot_v3.4.4-stable_mono_win32.zip',
+    ':3.4.4::windows:32:mono'           : 'https://downloads.tuxfamily.org/godotengine/3.4.4/mono/Godot_v3.4.4-stable_mono_win64.zip',
+# 3.4.5
+    ':3.4.5::darwin::'                  : 'https://downloads.tuxfamily.org/godotengine/3.4.5/rc1/Godot_v3.4.5-rc1_osx.universal.zip',
+    ':3.4.5::linux:32:'                 : 'https://downloads.tuxfamily.org/godotengine/3.4.5/rc1/Godot_v3.4.5-rc1_x11.32.zip',
+    ':3.4.5::linux:64:'                 : 'https://downloads.tuxfamily.org/godotengine/3.4.5/rc1/Godot_v3.4.5-rc1_x11.64.zip',
+    ':3.4.5::windows:64:'               : 'https://downloads.tuxfamily.org/godotengine/3.4.5/rc1/Godot_v3.4.5-rc1_win64.exe.zip',
+    ':3.4.5::windows:32:'               : 'https://downloads.tuxfamily.org/godotengine/3.4.5/rc1/Godot_v3.4.5-rc1_win32.exe.zip',
+    ':3.4.5::darwin::mono'              : 'https://downloads.tuxfamily.org/godotengine/3.4.5/rc1/mono/Godot_v3.4.5-rc1_mono_osx.universal.zip',
+    ':3.4.5::linux:32:mono'             : 'https://downloads.tuxfamily.org/godotengine/3.4.5/rc1/mono/Godot_v3.4.5-rc1_mono_x11_32.zip',
+    ':3.4.5::linux:64:mono'             : 'https://downloads.tuxfamily.org/godotengine/3.4.5/rc1/mono/Godot_v3.4.5-rc1_mono_x11_64.zip',
+    ':3.4.5::windows:64:mono'           : 'https://downloads.tuxfamily.org/godotengine/3.4.5/rc1/mono/Godot_v3.4.5-rc1_mono_win32.zip',
+    ':3.4.5::windows:32:mono'           : 'https://downloads.tuxfamily.org/godotengine/3.4.5/rc1/mono/Godot_v3.4.5-rc1_mono_win64.zip',
+# 3.5
+    ':3.5::darwin::'                    : 'https://downloads.tuxfamily.org/godotengine/3.5/Godot_v3.5-stable_osx.universal.zip',
+    ':3.5::linux:32:'                   : 'https://downloads.tuxfamily.org/godotengine/3.5/Godot_v3.5-stable_x11.32.zip',
+    ':3.5::linux:64:'                   : 'https://downloads.tuxfamily.org/godotengine/3.5/Godot_v3.5-stable_x11.64.zip',
+    ':3.5::windows:64:'                 : 'https://downloads.tuxfamily.org/godotengine/3.5/Godot_v3.5-stable_win64.exe.zip',
+    ':3.5::windows:32:'                 : 'https://downloads.tuxfamily.org/godotengine/3.5/Godot_v3.5-stable_win32.exe.zip',
+    ':3.5::darwin::mono'                : 'https://downloads.tuxfamily.org/godotengine/3.5/mono/Godot_v3.5-stable_mono_osx.universal.zip',
+    ':3.5::linux:32:mono'               : 'https://downloads.tuxfamily.org/godotengine/3.5/mono/Godot_v3.5-stable_mono_x11_32.zip',
+    ':3.5::linux:64:mono'               : 'https://downloads.tuxfamily.org/godotengine/3.5/mono/Godot_v3.5-stable_mono_x11_64.zip',
+    ':3.5::windows:64:mono'             : 'https://downloads.tuxfamily.org/godotengine/3.5/mono/Godot_v3.5-stable_mono_win32.zip',
+    ':3.5::windows:32:mono'             : 'https://downloads.tuxfamily.org/godotengine/3.5/mono/Godot_v3.5-stable_mono_win64.zip',
+# 3.5.1
+    ':3.5.1::darwin::'                  : 'https://downloads.tuxfamily.org/godotengine/3.5.1/rc1/Godot_v3.5.1-rc1_osx.universal.zip',
+    ':3.5.1::linux:32:'                 : 'https://downloads.tuxfamily.org/godotengine/3.5.1/rc1/Godot_v3.5.1-rc1_x11.32.zip',
+    ':3.5.1::linux:64:'                 : 'https://downloads.tuxfamily.org/godotengine/3.5.1/rc1/Godot_v3.5.1-rc1_x11.64.zip',
+    ':3.5.1::windows:64:'               : 'https://downloads.tuxfamily.org/godotengine/3.5.1/rc1/Godot_v3.5.1-rc1_win64.exe.zip',
+    ':3.5.1::windows:32:'               : 'https://downloads.tuxfamily.org/godotengine/3.5.1/rc1/Godot_v3.5.1-rc1_win32.exe.zip',
+    ':3.5.1::darwin::mono'              : 'https://downloads.tuxfamily.org/godotengine/3.5/rc1/mono/Godot_v3.5.1-rc1_mono_osx.universal.zip',
+    ':3.5.1::linux:32:mono'             : 'https://downloads.tuxfamily.org/godotengine/3.5/rc1/mono/Godot_v3.5.1-rc1_mono_x11_32.zip',
+    ':3.5.1::linux:64:mono'             : 'https://downloads.tuxfamily.org/godotengine/3.5/rc1/mono/Godot_v3.5.1-rc1_mono_x11_64.zip',
+    ':3.5.1::windows:64:mono'           : 'https://downloads.tuxfamily.org/godotengine/3.5/rc1/mono/Godot_v3.5.1-rc1_mono_win32.zip',
+    ':3.5.1::windows:32:mono'           : 'https://downloads.tuxfamily.org/godotengine/3.5/rc1/mono/Godot_v3.5.1-rc1_mono_win64.zip',
+# 4.0
+    ':4.0::darwin::'                	: 'https://downloads.tuxfamily.org/godotengine/4.0/beta1/Godot_v4.0-beta1_osx.universal.zip',
+    ':4.0::linux:32:'               	: 'https://downloads.tuxfamily.org/godotengine/4.0/beta1/Godot_v4.0-beta1_x11.32.zip',
+    ':4.0::linux:64:'               	: 'https://downloads.tuxfamily.org/godotengine/4.0/beta1/Godot_v4.0-beta1_x11.64.zip',
+    ':4.0::windows:64:'             	: 'https://downloads.tuxfamily.org/godotengine/4.0/beta1/Godot_v4.0-beta1_win64.exe.zip',
+    ':4.0::windows:32:'             	: 'https://downloads.tuxfamily.org/godotengine/4.0/beta1/Godot_v4.0-beta1_win32.exe.zip',
+    ':4.0::darwin::mono'              	: 'https://downloads.tuxfamily.org/godotengine/4.0/beta1/mono/Godot_v4.0-beta1_mono_osx.universal.zip',
+    ':4.0::linux:32:mono'             	: 'https://downloads.tuxfamily.org/godotengine/4.0/beta1/mono/Godot_v4.0-beta1_mono_x11_32.zip',
+    ':4.0::linux:64:mono'             	: 'https://downloads.tuxfamily.org/godotengine/4.0/beta1/mono/Godot_v4.0-beta1_mono_x11_64.zip',
+    ':4.0::windows:64:mono'           	: 'https://downloads.tuxfamily.org/godotengine/4.0/beta1/mono/Godot_v4.0-beta1_mono_win32.zip',
+    ':4.0::windows:32:mono'           	: 'https://downloads.tuxfamily.org/godotengine/4.0/beta1/mono/Godot_v4.0-beta1_mono_win64.zip',
 }
